##  Editing Existing Templates
  1. Go to the Diagrams tab and select Fact Sheet Shape Templates.
  2. Select the template you want to modify and choose Edit.
  3. Select your preferred shapes from the shape library and add them to the canvas.
  4. Select added shapes and assign them to fact sheet types using the Fact Sheet Type dropdown. If the fact sheet type has subtypes, select the subtype from the Subtype dropdown.
  5. Adjust the colors, styles, and shapes using the format panel.
  6. Choose Save As and enter a name for your template.
  7. Choose Save.
